@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ Crypt::LE - Let's Encrypt API interfacing module.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =head1 SYNOPSIS
 
@@ -209,7 +209,7 @@ Enables automatic retrieval of the resource directory (required for normal API p
 
 =item C<delay>
 
-Specifies the time in seconds to wait before Let's Encrypt servers are are checked for the challenge verification results again. By default set to 2 seconds.
+Specifies the time in seconds to wait before Let's Encrypt servers are checked for the challenge verification results again. By default set to 2 seconds.
 Non-integer values are supported (so for example you can set it to 1.5 if you like).
 
 =back
@@ -609,7 +609,7 @@ The account key fingerprint
 =back
 
 The type of the challenge accepted is optional and it is 'http' by default. The following values are currently available: 'http', 'tls', 'dns'. 
-New values which might be added by Let's Encrypt will be supported automaticaly. While currently all domains being processed share the same type
+New values which might be added by Let's Encrypt will be supported automatically. While currently all domains being processed share the same type
 of challenge, it might be changed in the future versions.
 
 On error you can call failed_domains() method, which returns an array reference to domain names for which the challenge was not accepted successfully.
@@ -637,7 +637,7 @@ B<handle_challenge_dns()>
 
 You can use L<Crypt::LE::Challenge::Simple> example module as a template.
  
-Returns: OK | ERROR | INVALID_DATA.
+Returns: OK | INVALID_DATA | ERROR.
 
 =cut
 
@@ -1176,7 +1176,7 @@ L<http://search.cpan.org/dist/Crypt-LE/>
 Copyright 2016 Alexander Yezhov.
 
 This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
+under the terms of the Artistic License (2.0). You may obtain a
 copy of the full license at:
 
 L<http://www.perlfoundation.org/artistic_license_2_0>
